/*
 * @copyright Copyright (c) 2021 Jonas Heinrich <onny@project-insanity.org>
 *
 * @author Jonas Heinrich <onny@project-insanity.org>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */

import { ShowApi } from './../services/ShowApi'

const apiClient = new ShowApi()

export default {
	state: {
		shows: [],
	},
	getters: {
		subscribedShows: state => {
			return state.shows
		},
		showById: state => (id) => {
			return state.shows.find((show) => show.id === id)
		},
		showExists: state => (id) => {
			return state.shows.some((show) => show.id === id)
		},
	},
	mutations: {
		addShow(state, show) {
			state.shows.push(show)
		},
		removeShow(state, show) {
			const existingIndex = state.shows.findIndex(_show => _show.id === show.id)
			if (existingIndex !== -1) {
				state.shows.splice(existingIndex, 1)
			}
		},
		setShows(state, shows) {
			state.shows = shows
		},
	},
	actions: {
		async loadShows({ commit }) {
			const shows = await apiClient.loadShows()
			commit('setShows', shows)
		},
		addShow({ commit }, show) {
			apiClient.addShow(show)
				.then((show) => {
					commit('addShow', show)
				})
		},
		removeShow({ commit }, show) {
			apiClient.removeShow(show)
				.then((show) => {
					commit('removeShow', show)
				})
		},
	},
}
